# TNFR IO — Canonical Module Hub (Single Source of Truth)

English-only hub for input/output formats and serializers.

- Canonical physics/invariants: `AGENTS.md`
- Grammar: `UNIFIED_GRAMMAR_RULES.md`

## Scope
- CSV/JSONL export, logs, and related helpers
